# Table of Contents

- [platform-modeling-guidelines](<./platform-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Platform Modeling Guidelines](<./Platform-Modeling-Guidelines.md>)
  - [Definition](<./Platform-Modeling-Guidelines/Definition.md>)
  - [Description](<./Platform-Modeling-Guidelines/Description.md>)
  - [Guidelines and Best Practices](<./Platform-Modeling-Guidelines/Guidelines-and-Best-Practices.md>)
  - [Antipatterns](<./Platform-Modeling-Guidelines/Antipatterns.md>)
  - [Applicable Use Cases](<./Platform-Modeling-Guidelines/Applicable-Use-Cases.md>)
  - [Insights from Platform Fact Sheet](<./Platform-Modeling-Guidelines/Insights-from-Platform-Fact-Sheet.md>)
  - [Related Information](<./Platform-Modeling-Guidelines/Related-Information.md>)
  - [We'd love your feedback!](<./Platform-Modeling-Guidelines/Wed-love-your-feedback.md>)
